@@ -368,7 +368,7 @@ class IndentedContextualConfig(dict):
                             context["config"], **match.groupdict())
 
                     except:
-                        print("parse() with: type(cmd)=" + repr(type(cmd)),
+                        print("%s.parse()" % repr(type(cmd)),
                               file=sys.stderr)
 
                         raise
@@ -398,6 +398,20 @@ class IndentedContextualConfig(dict):
                             print("*> entering context:", cmd.enter_context)
 
 
+                        # raise an error if this command enteres a new
+                        # context but the parse() method didn't return
+                        # a configuration item
+                        #
+                        # (safety check to avoid broken parse() methods
+                        # causing their subconfiguration information to
+                        # be lost)
+
+                        if new_config is None:
+                            raise AssertionError(
+                                "%s.parse() returned None but has "
+                                "enter_context" % repr(type(cmd)))
+
+
                         new_context["name"] = cmd.enter_context
 
 
