@@ -715,6 +715,10 @@ class DiffConfig:
         will be raised.
         """
 
+        if cvt.block not in self._cvts:
+            raise KeyError("block: %s not found for converter: %s"
+                                % (cvt.block, type(self)))
+
         self._cvts[cvt.block].append(cvt)
 
 
