@@ -43,6 +43,10 @@ class CiscoIOSDiffConfig(DiffConfig):
             # disruptive
             "int-shutdown",
 
+            # some changes must be done before things can be configured
+            # that use them (e.g. HSRP version and high HSRP groups)
+            "int-pre",
+
             # we don't need to do anything particular in advance
             None,
 
@@ -50,6 +54,10 @@ class CiscoIOSDiffConfig(DiffConfig):
             # changes on them
             "int-vrf", "int-addr",
 
+            # some changes must be done after things use them have been
+            # unconfigured (e.g. HSRP version and high HSRP groups)
+            "int-post",
+
             # if we're enabling interfaces, we do that after we've done
             # all the other configuration on them
             "int-noshutdown",
