@@ -39,9 +39,11 @@ _INTERFACE_CANONICALS = {
     "fastethernet": "Fa",
     "gigabitethernet": "Gi",
     "tengigabitethernet": "Te",
+    "twentyfivegigethernet": "Twe",
     "fortygigabitethernet": "Fo",
+    "hundredgigethernet": "Hu",
     "port-channel": "Po",
-    "vl": "Vlan"
+    "vl": "Vlan",
 }
 
 
@@ -666,8 +668,12 @@ def explain_diffs(old, new, indent="", prefix="", to_str_func=None):
 
 
 # regular expression for matching physical interface names
+#
+# note that it will only match interfaces of the form
+# "<type><num>[/<num2>[/<num3>[/...]]]" and this excludes subinterfaces,
+# where the final number with have a dot in it
 
-_INTERFACE_PHYSICAL_RE = re.compile("^(Mgmt|Eth|Fa|Gi|Te|Fo)\d",
+_INTERFACE_PHYSICAL_RE = re.compile("^(Mgmt|Eth|Fa|Gi|Te|Twe|Fo|Hu)\d+(/\d+)*$",
                                     re.IGNORECASE)
 
 
@@ -675,6 +681,10 @@ def is_int_physical(i):
     """This function returns if a particular interface is physical or
     not.  The names it matches are those that the are used as the
     canonical ones in the parser.
+
+    The purpose of this function is primarily to work out if an
+    interface can be deleted with "no interface ..." so excludes
+    subinterfaces of physical interfaces.
     """
 
     return _INTERFACE_PHYSICAL_RE.match(i)
